import { Function } from "aws-cdk-lib/aws-cloudfront";
import { Construct } from "constructs";
import { DomainName } from "../../aws-route53";
export declare type TrailingSlashBehavior = "None" | "ForwardToIndex" | "RedirectNoSlash";
export declare type NoFileIndexBehavior = "None" | "ForwardToIndex" | "RedirectToSlash";
export declare type RobotsBehavior = "None" | "Allow" | "Disallow";
export interface WebsiteRedirectFunctionProps {
    /**
     * Optional domain to redirect to if the host header does not match.
     */
    readonly apexDomain?: string | DomainName;
    /**
     * The default file to request when the URI ends with a '/'. Set to en empty string to disable.
     *
     * @default "index.html"
     */
    readonly indexFile?: string;
    /**
     * Sets the behavior of paths with trailing slashes. Default is "ForwardToIndex".
     *
     * @default "ForwardToIndex"
     */
    readonly trailingSlashBehavior?: TrailingSlashBehavior;
    /**
     * Sets the behavior of paths with no file extension. Default is "None"
     *
     * @default "None"
     */
    readonly noFileExtensionBehavior?: NoFileIndexBehavior;
    /**
     * Sets the behavior for /robots.txt requests. Default is "Allow".
     */
    readonly robotsBehavior?: RobotsBehavior;
}
export declare class WebsiteRedirectFunction extends Function {
    constructor(scope: Construct, id: string, props: WebsiteRedirectFunctionProps);
}
